@@ -5,7 +5,8 @@ from .server import server
 
 
 def main():
-    assert isfile(argv[1])
+    if not isfile(argv[1]):
+        raise FileNotFoundError(argv[1])
 
     host, port = argv[2].split(":") if argv[2:] else ("0.0.0.0", 8080)
     server(argv[1], host=host, port=int(port))
